spoon.spoonstream.SpoonStream

Package spoon :: Module spoonstream :: Class SpoonStream |
[hide private]
[frames] | no frames]

# Class SpoonStream

source code

    object --+
             |
            SpoonStream

SpoonStream implements an object stream. This will take either a file like object or a socket like object

Instance Methods | [hide private]
`` | __init__(self, fd, compress=False) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | read(self, cnt=None)
`` | recv(self, cnt=None)
`` | write(self, obj)
`` | send(self, obj)
`` | close(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fd, compress=False) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### read(self, cnt=None) | source code
None

### recv(self, cnt=None) | source code
None

### write(self, obj) | source code
None

### send(self, obj) | source code
None

### close(self) | source code
None